==> paraview_trame_components-0.5.0.tar.gz: paraview_trame_components-0.5.0/ptc/core.py <==
from paraview import simple
from trame.app import get_server
from trame.decorators import TrameApp, change, controller
from trame.ui.vuetify3 import VAppLayout
from trame.widgets import html
from trame.widgets import paraview as pv_widgets

from .layouts import create_layout_manager


class InvalidContainerNameError(Exception):
    def __init__(self, name):
        super().__init__(f"Container {name} not available")


@TrameApp()
class Viewer:
    def __init__(self, views=None, from_state=False, server=None, template_name="main"):
        self.layout_factory = create_layout_manager(self)
        self.template_name = template_name
        self.server = get_server(server)
        self.views = views
        self.html_views = []
        self.proxy_views = []
        self.ui = None
        if self.views is None or len(self.views) == 0:
            self.views = [simple.GetActiveView()]

        if from_state:
            for view in self.views:
                view.MakeRenderWindowInteractor(True)

        self._build_ui()

    @property
    def state(self):
        return self.server.state

    @property
    def ctrl(self):
        return self.server.controller

    def start(self, *args, **kwargs):
        self.ui.flush_content()
        self.server.start(*args, **kwargs)

    @change("active_view_id")
    def _active_view(self, active_view_id, **_):
        if active_view_id < len(self.proxy_views):
            simple.SetActiveView(self.proxy_views[active_view_id])
            if self.server.controller.on_active_view_change.exists():
                self.server.controller.on_active_view_change()

    def _build_ui(self):
        self.state.active_view_id = 1
        with VAppLayout(
            self.server, template_name=self.template_name, full_height=True
        ) as layout:
            self.ui = layout
            with html.Div(classes="d-flex align-stretch fill-height"):
                for view in self.views:
                    if isinstance(view, list | tuple):
                        with html.Div(
                            classes="d-flex align-stretch fill-height flex-column flex-grow-1 flex-shrink-1"
                        ):
                            for v in view:
                                view_id = len(self.html_views)
                                with html.Div(
                                    classes="flex-grow-1 flex-shrink-1 border-thin",
                                    style=(
                                        f"{{ overflow: 'hidden', zIndex: 0, padding: '1px', margin: '1px', outline: active_view_id === {view_id} ? 'solid 1.5px blue' : 'none' }}",
                                    ),
                                    click=f"active_view_id = {view_id}",
                                ):
                                    view_html = pv_widgets.VtkRemoteView(
                                        v,
                                        interactive_ratio=1,
                                        style="z-index: -1;",
                                    )
                                    self.ctrl.view_update.add(view_html.update)
                                    self.ctrl.view_reset_camera.add(
                                        view_html.reset_camera
                                    )
                                    self.html_views.append(view_html)
                                    self.proxy_views.append(v)
                    else:
                        view_id = len(self.html_views)
                        with html.Div(
                            classes="flex-grow-1 flex-shrink-1 border-thin",
                            style=(
                                f"{{ overflow: 'hidden', zIndex: 0, padding: '1px', margin: '1px', outline: active_view_id === {view_id} ? 'solid 1.5px blue' : 'none' }}",
                            ),
                            click=f"active_view_id = {view_id}",
                        ):
                            view_html = pv_widgets.VtkRemoteView(
                                view,
                                interactive_ratio=1,
                                style="z-index: -1;",
                            )
                            self.ctrl.view_update.add(view_html.update)
                            self.ctrl.view_reset_camera.add(view_html.reset_camera)
                            self.html_views.append(view_html)
                            self.proxy_views.append(view)

    @controller.add("on_data_change")
    def update(self):
        self.ctrl.view_update()

    def reset_camera(self):
        self.ctrl.view_reset_camera()

    def __getattr__(self, key):
        """Lookup a layout specific container."""
        manager = self.layout_factory.get_manager(key)

        if manager is None:
            raise InvalidContainerNameError(key)

        with self.ui:
            return manager.create_container(key)

==> paraview_trame_components-0.7.0.tar.gz: paraview_trame_components-0.7.0/ptc/core.py <==
from paraview import simple
from trame.app import get_server
from trame.decorators import TrameApp, change, controller
from trame.ui.vuetify3 import VAppLayout
from trame.widgets import html
from trame.widgets import paraview as pv_widgets
from trame.widgets import vuetify3 as v3

from .layouts import create_layout_manager


class InvalidContainerNameError(Exception):
    def __init__(self, name):
        super().__init__(f"Container {name} not available")


@TrameApp()
class Viewer:
    def __init__(self, views=None, from_state=False, server=None, template_name="main"):
        self.layout_factory = create_layout_manager(self)
        self.template_name = template_name
        self.server = get_server(server)
        self.views = views
        self.html_views = []
        self.proxy_views = []
        self.ui = None
        if self.views is None or len(self.views) == 0:
            view = simple.GetActiveView()
            if view is None:
                view = simple.CreateRenderView()
            self.views = [view]

        if from_state:
            for view in self.views:
                view.MakeRenderWindowInteractor(True)

        self._build_ui()

    @property
    def state(self):
        return self.server.state

    @property
    def ctrl(self):
        return self.server.controller

    def start(self, *args, **kwargs):
        self.ui.flush_content()
        self.server.start(*args, **kwargs)

    @change("active_view_id")
    def _active_view(self, active_view_id, **_):
        if active_view_id < len(self.proxy_views):
            simple.SetActiveView(self.proxy_views[active_view_id])
            if self.server.controller.on_active_view_change.exists():
                self.server.controller.on_active_view_change()

    def _build_ui(self):
        self.state.active_view_id = 1
        with VAppLayout(
            self.server, template_name=self.template_name, full_height=True
        ) as layout:
            self.ui = layout
            with html.Div(classes="d-flex align-stretch fill-height"):
                for view in self.views:
                    if isinstance(view, list | tuple):
                        with html.Div(
                            classes="d-flex align-stretch fill-height flex-column flex-grow-1 flex-shrink-1"
                        ):
                            for v in view:
                                view_id = len(self.html_views)
                                with html.Div(
                                    classes="flex-grow-1 flex-shrink-1 border-thin position-relative",
                                    style=(
                                        f"{{ overflow: 'hidden', zIndex: 0, padding: '1px', margin: '1px', outline: active_view_id === {view_id} ? 'solid 1.5px blue' : 'none' }}",
                                    ),
                                    click=f"active_view_id = {view_id}",
                                ):
                                    view_html = pv_widgets.VtkRemoteView(
                                        v,
                                        interactive_ratio=1,
                                        style="z-index: -1;",
                                    )
                                    v3.VBtn(
                                        icon="mdi-crop-free",
                                        click=view_html.reset_camera,
                                        classes="position-absolute",
                                        style="top: 1rem;right: 1rem; z-index: 1;",
                                        variant="outlined",
                                        size="small",
                                    )
                                    self.ctrl.on_data_loaded.add(view_html.reset_camera)
                                    self.ctrl.view_update.add(view_html.update)
                                    self.ctrl.view_reset_camera.add(
                                        view_html.reset_camera
                                    )
                                    self.html_views.append(view_html)
                                    self.proxy_views.append(v)
                    else:
                        view_id = len(self.html_views)
                        with html.Div(
                            classes="flex-grow-1 flex-shrink-1 border-thin position-relative",
                            style=(
                                f"{{ overflow: 'hidden', zIndex: 0, padding: '1px', margin: '1px', outline: active_view_id === {view_id} ? 'solid 1.5px blue' : 'none' }}",
                            ),
                            click=f"active_view_id = {view_id}",
                        ):
                            view_html = pv_widgets.VtkRemoteView(
                                view,
                                interactive_ratio=1,
                                style="z-index: -1;",
                            )
                            v3.VBtn(
                                icon="mdi-crop-free",
                                click=view_html.reset_camera,
                                classes="position-absolute",
                                style="top: 1rem;right: 1rem; z-index: 1;",
                                variant="outlined",
                                size="small",
                            )

                            self.ctrl.view_update.add(view_html.update)
                            self.ctrl.view_reset_camera.add(view_html.reset_camera)
                            self.ctrl.on_data_loaded.add(view_html.reset_camera)
                            self.html_views.append(view_html)
                            self.proxy_views.append(view)

    @controller.add("on_data_change")
    def update(self):
        self.ctrl.view_update()

    def reset_camera(self):
        self.ctrl.view_reset_camera()

    def __getattr__(self, key):
        """Lookup a layout specific container."""
        manager = self.layout_factory.get_manager(key)

        if manager is None:
            raise InvalidContainerNameError(key)

        with self.ui:
            return manager.create_container(key)
